package Pcore::Ext::Lib::modern::Profile;

use Pcore -l10n;
use Pcore::CDN::Static::FA qw[:ALL];

sub EXT_controller : Extend('Ext.app.ViewController') {
    return {
        changePassword => func <<"JS",
            this.getView().hide();

            Ext.create({
                xtype: "$type{'/pcore/core/Viewport/change_password'}"
            }).show();
JS
    };
}

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::Ext::Lib::modern::Profile

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 ATTRIBUTES

=head1 METHODS

=head1 SEE ALSO

=cut
