#!/usr/bin/env perl

package main v0.1.0;

use Pcore;
use Test::More;

our $TESTS = 1;

plan tests => $TESTS;

# replace with actual test
ok( 1, 'test_name' );

done_testing $TESTS;

1;
__END__
=pod

=encoding utf8

=cut
